about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--main.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/main.go b/main.go
index da2fdb0..677f405 100644
--- a/main.go
+++ b/main.go
@@ -68,8 +68,8 @@ func NFW(w http.ResponseWriter, r *http.Request) {
 	}
 }
 
-// Index handles request on the / endpoint
-func Index(w http.ResponseWriter, r *http.Request) {
+// IndexHandler handles request on the / endpoint
+func IndexHandler(w http.ResponseWriter, r *http.Request) {
 	log.Print(fmt.Fprintln(w, "usage: nfw.docker.localhost/NFW?x=<x>&y=<y>&z=<z>"))
 }
 
@@ -77,7 +77,7 @@ func main() {
 	router := mux.NewRouter()
 
 	// routes
-	router.HandleFunc("/", Index).Methods("GET")
+	router.HandleFunc("/", IndexHandler).Methods("GET")
 	router.HandleFunc("/NFW", NFW).Methods("GET")
 
 	log.Println("Starting the service on port localhost:8081")